@@ -3,7 +3,8 @@ import contextlib
 import functools
 import uuid
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Protocol, override
+from typing import TYPE_CHECKING, Any, Protocol
+from typing_extensions import override
 
 from nonebot import on_fullmatch, on_message
 from nonebot.log import logger
@@ -13,7 +14,7 @@ from ..api import API as BaseAPI
 from ..api import register_api
 from ..help_doc import descript, message_alia
 from ..utils import Result, debug_log, export
-from .send_ark import SendArk
+from ._send_ark import SendArk
 
 if TYPE_CHECKING:
 
