@@ -1,4 +1,3 @@
-from collections.abc import Awaitable
 from typing import TYPE_CHECKING, ClassVar
 
 from nonebot_plugin_alconna.uniseg import Receipt
@@ -27,16 +26,16 @@ class User(Interface):
         parameters=dict(msg="需要发送的消息"),
     )
     @debug_log
-    def send(self, msg: T_Message) -> Awaitable[Receipt]:
-        return self.api.send_prv(self.uid, msg)
+    async def send(self, msg: T_Message) -> Receipt:
+        return await self.api.send_prv(self.uid, msg)
 
     @descript(
         description="向用户发送私聊合并转发消息",
         parameters=dict(msgs="需要发送的消息列表"),
     )
     @debug_log
-    def send_fwd(self, msgs: T_ForwardMsg) -> Awaitable[Receipt]:
-        return self.api.send_prv_fwd(self.uid, msgs)
+    async def send_fwd(self, msgs: T_ForwardMsg) -> Receipt:
+        return await self.api.send_prv_fwd(self.uid, msgs)
 
     def __repr__(self):
         return f"{self.__class__.__name__}(user_id={self.uid})"
