@@ -3,18 +3,17 @@ from pathlib import Path
 from typing import Any
 
 from nonebot_plugin_alconna.uniseg import At, Image, Reply, Text, UniMessage
-from nonebot_plugin_datastore import get_plugin_data
+from nonebot_plugin_localstore import get_plugin_data_dir
 
 from ..constant import T_ConstVar, T_Context, T_OptConstVar
 
 default_context: T_Context = {}
 
 
-def context_var[T: Any](item: T, name: str | None = None) -> T:
+def context_var(item: Any, name: str | None = None) -> None:
     key = name or getattr(item, "__name__", None)
     assert key is not None, f"Name for {item!r} cannot be empty"
     default_context[key] = item
-    return item
 
 
 context_var((None, None), "__exception__")
@@ -24,7 +23,7 @@ context_var(lambda x: Reply(id=str(x)), "Reply")
 
 
 def _const_var_path(uin: str) -> Path:
-    fp = get_plugin_data().data_dir / f"{uin}.json"
+    fp = get_plugin_data_dir() / f"{uin}.json"
     if not fp.exists():
         fp.write_text("{}")
     return fp
